# Export main functions
export(glme.gev)
export(glme.gev11)
export(glme.like)
export(init.glme)
export(pargev.kfix)
export(MS_pk)
export(new_pf_norm)
export(pk.norm.stnary)
export(pk.beta)
export(pk.beta.stnary)

# Non-stationary GEV11 methods (new in v2.0.0)
export(lme.gev11)
export(strup.gev11)
export(GN16.gev11)
export(ran.gev_all)

# S3 methods for fitted objects (v2.0.0)
S3method(print, glme)
S3method(summary, glme)
S3method(plot, glme)
S3method(print, glme11)
S3method(summary, glme11)
S3method(plot, glme11)
S3method(print, lme11)
S3method(summary, lme11)
S3method(plot, lme11)
S3method(print, magev)
S3method(summary, magev)
S3method(plot, magev)

# Shin et al. (2025b) compatibility functions
export(nsgev)
export(gado.prop_11)
export(quagev.NS)

# Shin et al. (2026) Model Averaging function
export(ma.gev)

# MAGEV Plotting functions
export(magev.ksensplot)
export(magev.qqplot)
export(magev.rlplot)

# Imports from lmomco
importFrom("lmomco", "lmoms", "pargev", "lmoms.cov", "vec2par", "lmomgev", "lmorph", "are.lmom.valid", "TLmoms", "lmomgum", "quagev", "pargum", "rlmomco")

# Imports from stats
importFrom("stats", "optim", "rnorm", "runif", "integrate", "dnorm", "lm", "var", "sd", "cov", "median", "quantile", "cor", "spline", "qchisq", "na.omit", "ppoints")

# Imports from methods
importFrom("methods", "is")

# Imports from nleqslv
importFrom("nleqslv", "nleqslv")

# Imports from robustbase
importFrom("robustbase", "lmrob")

# Imports for MAGEV
importFrom("ismev", "gev.fit")
importFrom("Rsolnp", "solnp")
importFrom("zoo", "rollmean")
importFrom("graphics", "plot", "abline", "text", "par", "axis", "lines", "points")
