% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/magev_helpers.R
\name{gev.xilik}
\alias{gev.xilik}
\title{GEV negative log-likelihood with fixed xi}
\usage{
gev.xilik(a, xifix = NULL, xdat = NULL)
}
\arguments{
\item{a}{Numeric vector of (mu, sigma).}

\item{xifix}{Fixed shape parameter value.}

\item{xdat}{Numeric vector of data.}
}
\value{
Negative log-likelihood value (scalar). Returns 10^6 if invalid.
}
\description{
Internal function that computes the negative log-likelihood
for the GEV distribution with a fixed shape parameter (Hosking parameterization).
}
\keyword{internal}
