% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/magev_helpers.R
\name{gev.xilik2}
\alias{gev.xilik2}
\title{GEV negative log-likelihood with fixed xi (wrapper)}
\usage{
gev.xilik2(a, xifix = xifix, xdat = xdat)
}
\arguments{
\item{a}{Numeric vector of (mu, sigma).}

\item{xifix}{Fixed shape parameter value.}

\item{xdat}{Numeric vector of data.}
}
\value{
Negative log-likelihood value (scalar).
}
\description{
Internal wrapper function that calls \code{gev.xilik()}.
}
\keyword{internal}
